@@ -15,7 +15,6 @@ use DateTime;
 use base qw(Vimana::Accessor);
 __PACKAGE__->mk_accessors( qw(package options) );
 
-
 $| = 1;
 
 =encoding utf8
@@ -33,7 +32,10 @@ Vimana::AutoInstall
 sub inspect_text_content {
     my $self = shift;
     my $content = $self->package->content;
-    return 'colors' if $content =~ m/let\s+(g:)?colors_name\s*=/;
+    return 'colors'   if $content =~ m/^let\s+(g:)?colors_name\s*=/;
+    return 'syntax'   if $content =~ m/^syn[tax]* (?:match|region|keyword)/;
+    return 'compiler' if $content =~ m/^let\s+current_compiler\s*=/;
+    return 'indent'   if $content =~ m/^let\s+b:did_indent/;
     return undef;
 }
 
@@ -48,11 +50,11 @@ sub run {
     my $pkg = $self->package;
 
     if( $pkg->is_archive() ) {
-        $logger->info('Archive type file');
+        $logger->info('Archive file');
         return $self->install_from_archive;
     }
     elsif( $pkg->is_text() ) {
-        $logger->info('Text type file');
+        $logger->info('Plain Text file');
 
         my $type = $self->inspect_text_content;
         if ($type) {
@@ -85,6 +87,8 @@ sub install_to {
     my ( $self , $dir ) = @_;
     my $file = $self->package->file;
     my $target = File::Spec->join( runtime_path(), $dir );
+    File::Path::mkpath [ runtime_path() ];
+
     $logger->info( "Install $file to $target" );
     my $ret = fcopy( $file => $target );
     !$ret ? 
@@ -98,7 +102,7 @@ sub find_vimball_files {
     my @vimballs;
     File::Find::find(  sub {
             return unless -f $_;
-            push @vimballs , $_ if /\.vba$/;
+            push @vimballs , File::Spec->join($File::Find::dir , $_ ) if /\.vba$/;
         } , $out );
     return @vimballs;
 }
@@ -145,7 +149,7 @@ sub install_from_archive {
         my @files;
         File::Find::find(  sub {
                 return unless -f $_;
-                push @files , $_ if -f $_;
+                push @files , File::Spec->join( $File::Find::dir , $_ ) if -f $_;
             } , $out );
 
         my $nodes = $self->find_base_path( \@files );
@@ -211,7 +215,7 @@ sub find_base_path {
     my $nodes = {};
     for my $p ( @$paths ) {
         if ( $p =~ m{^(.*?/)?(plugin|doc|syntax|indent|colors|autoload|after|ftplugin)/.*?\.(vim|txt)$} ) {
-            $nodes->{ $1 || '' } += 2;
+            $nodes->{ $1 || '' } ++;
         }
     }
     return $nodes;
