@@ -5,6 +5,9 @@ use Vimana::Logger;
 use Vimana::Util;
 use Archive::Any;
 use LWP::Simple qw();
+use File::Spec;
+use File::Path;
+use File::Copy;
 use base qw(Vimana::Accessor);
 __PACKAGE__->mk_accessors( qw(
     cname
@@ -133,10 +136,40 @@ sub auto_install {
 
     require Vimana::AutoInstall;
     my $auto = Vimana::AutoInstall->new( { package => $self , options => \%args } );
-    return $auto->run();  # dry_run , verbose
+    return $auto->run();  # XXX: dry_run , verbose
 
 }
 
+=head2 $pkgfile->copy_to( '/path/to/file' )
+
+=cut
+
+sub copy_to {
+    my ( $self , $path ) = @_;
+    my $src = $self->file;
+    my ( $v, $dir, $file ) = File::Spec->splitpath($path);
+    File::Path::mkpath [ $dir ];
+
+    $logger->info( "Copying $src to $path" );
+    my $ret = File::Copy::copy( $src => $path );
+    $ret 
+        ?  $logger->info("Done")
+        :  $logger->error( $! ) ;
+    $ret;
+}
+
+
+=head2 $pkgfile->copy_to_rtp( $type )
+
+copy to vim runtime path
+
+=cut
+
+sub copy_to_rtp {
+    my ( $self, $type ) = @_ ;
+    my $target = File::Spec->join( runtime_path(), $type );
+    return $self->copy_to($target);
+}
 
 sub makefile_install {
 
